==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/outputs/FunctionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress

/**
 * A function object, containing all information associated with the named function. All functions are contained under a streaming job.
 * @property id Resource Id
 * @property name Resource name
 * @property properties The properties that are associated with a function.
 * @property type Resource type
 */
public data class FunctionResponse(
    public val id: String,
    public val name: String? = null,
    public val properties:
    Either<AggregateFunctionPropertiesResponse, ScalarFunctionPropertiesResponse>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.streamanalytics.outputs.FunctionResponse):
            FunctionResponse = FunctionResponse(
            id = javaType.id(),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            properties = javaType.properties().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.streamanalytics.kotlin.outputs.AggregateFunctionPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.streamanalytics.kotlin.outputs.ScalarFunctionPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }).orElse(null),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/outputs/FunctionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress

/**
 * A function object, containing all information associated with the named function. All functions are contained under a streaming job.
 * @property id Resource Id
 * @property name Resource name
 * @property properties The properties that are associated with a function.
 * @property type Resource type
 */
public data class FunctionResponse(
    public val id: String,
    public val name: String? = null,
    public val properties: Either<AggregateFunctionPropertiesResponse, ScalarFunctionPropertiesResponse>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.streamanalytics.outputs.FunctionResponse): FunctionResponse = FunctionResponse(
            id = javaType.id(),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            properties = javaType.properties().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.streamanalytics.kotlin.outputs.AggregateFunctionPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.streamanalytics.kotlin.outputs.ScalarFunctionPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }).orElse(null),
            type = javaType.type(),
        )
    }
}
